@@ -1,4 +1,4 @@
-from typing import Tuple, List, Dict, Any
+from typing import Any, Dict, List, Tuple
 
 from torch import nn
 
